==> zio-aws-appsync_2.12-5.17.267.7-sources.jar: zio/aws/appsync/model/EvaluateMappingTemplateResponse.scala <==
package zio.aws.appsync.model
import zio.aws.appsync.model.primitives.EvaluationResult
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class EvaluateMappingTemplateResponse(
    evaluationResult: Optional[EvaluationResult] = Optional.Absent,
    error: Optional[zio.aws.appsync.model.ErrorDetail] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appsync.model.EvaluateMappingTemplateResponse = {
    import EvaluateMappingTemplateResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appsync.model.EvaluateMappingTemplateResponse
      .builder()
      .optionallyWith(
        evaluationResult.map(value =>
          EvaluationResult.unwrap(value): java.lang.String
        )
      )(_.evaluationResult)
      .optionallyWith(error.map(value => value.buildAwsValue()))(_.error)
      .build()
  }
  def asReadOnly
      : zio.aws.appsync.model.EvaluateMappingTemplateResponse.ReadOnly =
    zio.aws.appsync.model.EvaluateMappingTemplateResponse.wrap(buildAwsValue())
}
object EvaluateMappingTemplateResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appsync.model.EvaluateMappingTemplateResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appsync.model.EvaluateMappingTemplateResponse =
      zio.aws.appsync.model.EvaluateMappingTemplateResponse(
        evaluationResult.map(value => value),
        error.map(value => value.asEditable)
      )
    def evaluationResult: Optional[EvaluationResult]
    def error: Optional[zio.aws.appsync.model.ErrorDetail.ReadOnly]
    def getEvaluationResult: ZIO[Any, AwsError, EvaluationResult] =
      AwsError.unwrapOptionField("evaluationResult", evaluationResult)
    def getError
        : ZIO[Any, AwsError, zio.aws.appsync.model.ErrorDetail.ReadOnly] =
      AwsError.unwrapOptionField("error", error)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appsync.model.EvaluateMappingTemplateResponse
  ) extends zio.aws.appsync.model.EvaluateMappingTemplateResponse.ReadOnly {
    override val evaluationResult: Optional[EvaluationResult] =
      zio.aws.core.internal
        .optionalFromNullable(impl.evaluationResult())
        .map(value => zio.aws.appsync.model.primitives.EvaluationResult(value))
    override val error: Optional[zio.aws.appsync.model.ErrorDetail.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.error())
        .map(value => zio.aws.appsync.model.ErrorDetail.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.appsync.model.EvaluateMappingTemplateResponse
  ): zio.aws.appsync.model.EvaluateMappingTemplateResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-appsync_2.13-6.20.58.2-sources.jar: zio/aws/appsync/model/EvaluateMappingTemplateResponse.scala <==
package zio.aws.appsync.model
import zio.aws.appsync.model.primitives.EvaluationResult
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class EvaluateMappingTemplateResponse(
    evaluationResult: Optional[EvaluationResult] = Optional.Absent,
    error: Optional[zio.aws.appsync.model.ErrorDetail] = Optional.Absent,
    logs: Optional[Iterable[String]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appsync.model.EvaluateMappingTemplateResponse = {
    import EvaluateMappingTemplateResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appsync.model.EvaluateMappingTemplateResponse
      .builder()
      .optionallyWith(
        evaluationResult.map(value =>
          EvaluationResult.unwrap(value): java.lang.String
        )
      )(_.evaluationResult)
      .optionallyWith(error.map(value => value.buildAwsValue()))(_.error)
      .optionallyWith(
        logs.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.logs)
      .build()
  }
  def asReadOnly
      : zio.aws.appsync.model.EvaluateMappingTemplateResponse.ReadOnly =
    zio.aws.appsync.model.EvaluateMappingTemplateResponse.wrap(buildAwsValue())
}
object EvaluateMappingTemplateResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appsync.model.EvaluateMappingTemplateResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appsync.model.EvaluateMappingTemplateResponse =
      zio.aws.appsync.model.EvaluateMappingTemplateResponse(
        evaluationResult.map(value => value),
        error.map(value => value.asEditable),
        logs.map(value => value)
      )
    def evaluationResult: Optional[EvaluationResult]
    def error: Optional[zio.aws.appsync.model.ErrorDetail.ReadOnly]
    def logs: Optional[List[String]]
    def getEvaluationResult: ZIO[Any, AwsError, EvaluationResult] =
      AwsError.unwrapOptionField("evaluationResult", evaluationResult)
    def getError
        : ZIO[Any, AwsError, zio.aws.appsync.model.ErrorDetail.ReadOnly] =
      AwsError.unwrapOptionField("error", error)
    def getLogs: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("logs", logs)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appsync.model.EvaluateMappingTemplateResponse
  ) extends zio.aws.appsync.model.EvaluateMappingTemplateResponse.ReadOnly {
    override val evaluationResult: Optional[EvaluationResult] =
      zio.aws.core.internal
        .optionalFromNullable(impl.evaluationResult())
        .map(value => zio.aws.appsync.model.primitives.EvaluationResult(value))
    override val error: Optional[zio.aws.appsync.model.ErrorDetail.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.error())
        .map(value => zio.aws.appsync.model.ErrorDetail.wrap(value))
    override val logs: Optional[List[String]] = zio.aws.core.internal
      .optionalFromNullable(impl.logs())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.appsync.model.EvaluateMappingTemplateResponse
  ): zio.aws.appsync.model.EvaluateMappingTemplateResponse.ReadOnly =
    new Wrapper(impl)
}
